<?php

// exit if accessed directly
if( ! defined( 'ABSPATH' ) ) exit;


// check if class already exists
if( !class_exists('custom_acf_field_validate_field') ) :


class custom_acf_field_validate_field extends acf_field {
	
	
	/*
	*  __construct
	*
	*  This function will setup the field type data
	*
	*  @type	function
	*  @date	5/03/2014
	*  @since	5.0.0
	*
	*  @param	n/a
	*  @return	n/a
	*/
	
	function __construct( $settings ) {
		
		/*
		*  name (string) Single word, no spaces. Underscores allowed
		*/
		
		$this->name = 'validate_field';
		
		
		/*
		*  label (string) Multiple words, can include spaces, visible when selecting a field type
		*/
		
		$this->label = __('Validation Field: RegEx', 'acf-field-validate');
		
		
		/*
		*  category (string) basic | content | choice | relational | jquery | layout | CUSTOM GROUP NAME
		*/
		
		$this->category = 'Validation Field (Webwolf)';
		
		
		/*
		*  defaults (array) Array of default settings which are merged into the field object. These are used later in settings
		*/
		
		$this->defaults = array(
			'pattern_regex_acf' => "/^[+]*[(]{0,1}[0-9]{1,4}[)]{0,1}[-\s\.0-9]*$/",
		);
		
		
		/*
		*  l10n (array) Array of strings that are used in JavaScript. This allows JS strings to be translated in PHP and loaded via:
		*  var message = acf._e('validate_field', 'error');
		*/
		
		$this->l10n = array(
			'error'	=> __('Error! Please enter a higher value', 'acf-field-validate'),
		);
		
		
		/*
		*  settings (array) Store plugin settings (url, path, version) as a reference for later use with assets
		*/
		
		$this->settings = $settings;
		
		
		// do not delete!
    	parent::__construct();
    	
	}
	
	
	/*
	*  render_field_settings()
	*
	*  Create extra settings for your field. These are visible when editing a field
	*
	*  @type	action
	*  @since	3.6
	*  @date	23/01/13
	*
	*  @param	$field (array) the $field being edited
	*  @return	n/a
	*/
	
	function render_field_settings( $field ) {
		
		/*
		*  acf_render_field_setting
		*
		*  This function will create a setting for your field. Simply pass the $field parameter and an array of field settings.
		*  The array of settings does not require a `value` or `prefix`; These settings are found from the $field array.
		*
		*  More than one setting can be added by copy/paste the above code.
		*  Please note that you must also have a matching $defaults value for the field name (font_size)
		*/
		

		acf_render_field_setting( $field, array(
			'label'			=> __('RegEx Custom Pattern','acf-field-validate'),
			'instructions'	=> __('Customise RegEx validation pattern','acf-field-validate'),
			'type'			=> 'text',
			'name'			=> 'pattern_regex_acf',
		));
		

	}
	
	
	
	function render_field( $field ) {
		
		
		

		//FOR TESTING (VAR DUMP): $field --------------------------------------------------------------
		// OPTIION FIELD

		echo '<pre>';
			print_r("Follow the patterns (or change it in field settings) e.g.:
			- (123) 456 7899
			- 123 321 123
			- (123)-456-7899
			- (48) 123 321 123
			- 123 456 7899
			- 1234567899");
		echo '</pre>';
		?>
		<input type="text" name="<?php echo esc_attr($field['name']) ?>" value="<?php echo esc_attr($field['value']) ?>"/>
		<?php
	}
	
		

}


// initialize
new custom_acf_field_validate_field( $this->settings );


// class_exists check
endif;

?>