<?php
/**
 * Plugin Name: ACF RegEx Validate Field
 * Description: ACF Validation field by your custom RegEx pattern
 * Author: Kamil Barwiński (WebWolf &copy;)
 * Version: 1.0.0 (Menu inc.). Last Update: 30.07.21
 * Author URI: http://webwolf.dev
 */


function validate_form_acf( $valid, $value, $field, $input_name ) {

    $pattern = $field['pattern_regex_acf'];
    $ex = preg_match($pattern, $value);

    if($ex >= 1 && strlen($value) > 8){

        //if value is already invalid.
        if( !$valid ) {

            $valid = "GOOD VALIDATION ";

         }
    }
    // bad validation
    else if($ex == 0){

        $valid = "BAD VALIDATION, TRY AGAIN";
    }
    return $valid;
}
add_filter('acf/validate_value/type=validate_field', 'validate_form_acf', 10, 4);
// validate by Custom type declared below


// exit if accessed directly
if( ! defined( 'ABSPATH' ) ) exit;


// check if class already exists
if( !class_exists('custom_acf_plugin_validate_field') ) :


class custom_acf_plugin_validate_field {
	
	var $settings;
	
	function __construct() {
		
		$this->settings = array(
			'version'	=> '1.0.0',
			'url'		=> plugin_dir_url( __FILE__ ),
			'path'		=> plugin_dir_path( __FILE__ )
		);
		
		
		add_action('acf/include_field_types', 	array($this, 'include_field')); // v5
		add_action('acf/register_fields', 		array($this, 'include_field')); // v4
	}
	
	
	
	function include_field( $version = false ) {
		
		// support empty $version
		if( !$version ) $version = 4;
		
		
		// load textdomain
		load_plugin_textdomain( 'acf-field-validate', false, plugin_basename( dirname( __FILE__ ) ) . '/lang' ); 
		
		
		// include
		include_once('fields/class-custom-acf-field-validate-field-v' . $version . '.php');
	}
	
}


// initialize
new custom_acf_plugin_validate_field();


// class_exists check
endif;
	

function validate_form_acf_add_menu_page(){

    add_menu_page("Change Validate Pattern with RegEx", "RegEx Validate Settings", 4, "");

}
